==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/ClusterPrincipalAssignmentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin

import com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs.builder
import com.pulumi.azurenative.kusto.kotlin.enums.ClusterPrincipalRole
import com.pulumi.azurenative.kusto.kotlin.enums.PrincipalType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Class representing a cluster principal assignment.
 * Azure REST API version: 2022-12-29. Prior API version in Azure Native 1.x: 2021-01-01.
 * Other available API versions: 2023-05-02, 2023-08-15.
 * ## Example Usage
 * ### KustoClusterPrincipalAssignmentsCreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var clusterPrincipalAssignment = new AzureNative.Kusto.ClusterPrincipalAssignment("clusterPrincipalAssignment", new()
 *     {
 *         ClusterName = "kustoCluster",
 *         PrincipalAssignmentName = "kustoprincipal1",
 *         PrincipalId = "87654321-1234-1234-1234-123456789123",
 *         PrincipalType = "App",
 *         ResourceGroupName = "kustorptest",
 *         Role = "AllDatabasesAdmin",
 *         TenantId = "12345678-1234-1234-1234-123456789123",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/kusto/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := kusto.NewClusterPrincipalAssignment(ctx, "clusterPrincipalAssignment", &kusto.ClusterPrincipalAssignmentArgs{
 * 			ClusterName:             pulumi.String("kustoCluster"),
 * 			PrincipalAssignmentName: pulumi.String("kustoprincipal1"),
 * 			PrincipalId:             pulumi.String("87654321-1234-1234-1234-123456789123"),
 * 			PrincipalType:           pulumi.String("App"),
 * 			ResourceGroupName:       pulumi.String("kustorptest"),
 * 			Role:                    pulumi.String("AllDatabasesAdmin"),
 * 			TenantId:                pulumi.String("12345678-1234-1234-1234-123456789123"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.kusto.ClusterPrincipalAssignment;
 * import com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var clusterPrincipalAssignment = new ClusterPrincipalAssignment("clusterPrincipalAssignment", ClusterPrincipalAssignmentArgs.builder()
 *             .clusterName("kustoCluster")
 *             .principalAssignmentName("kustoprincipal1")
 *             .principalId("87654321-1234-1234-1234-123456789123")
 *             .principalType("App")
 *             .resourceGroupName("kustorptest")
 *             .role("AllDatabasesAdmin")
 *             .tenantId("12345678-1234-1234-1234-123456789123")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:kusto:ClusterPrincipalAssignment kustoCluster/kustoprincipal1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Kusto/clusters/{clusterName}/principalAssignments/{principalAssignmentName}
 * ```
 * @property clusterName The name of the Kusto cluster.
 * @property principalAssignmentName The name of the Kusto principalAssignment.
 * @property principalId The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
 * @property principalType Principal type.
 * @property resourceGroupName The name of the resource group containing the Kusto cluster.
 * @property role Cluster principal role.
 * @property tenantId The tenant id of the principal
 */
public data class ClusterPrincipalAssignmentArgs(
    public val clusterName: Output<String>? = null,
    public val principalAssignmentName: Output<String>? = null,
    public val principalId: Output<String>? = null,
    public val principalType: Output<Either<String, PrincipalType>>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val role: Output<Either<String, ClusterPrincipalRole>>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs =
        com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs.builder()
            .clusterName(clusterName?.applyValue({ args0 -> args0 }))
            .principalAssignmentName(principalAssignmentName?.applyValue({ args0 -> args0 }))
            .principalId(principalId?.applyValue({ args0 -> args0 }))
            .principalType(
                principalType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .role(
                role?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterPrincipalAssignmentArgs].
 */
@PulumiTagMarker
public class ClusterPrincipalAssignmentArgsBuilder internal constructor() {
    private var clusterName: Output<String>? = null

    private var principalAssignmentName: Output<String>? = null

    private var principalId: Output<String>? = null

    private var principalType: Output<Either<String, PrincipalType>>? = null

    private var resourceGroupName: Output<String>? = null

    private var role: Output<Either<String, ClusterPrincipalRole>>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("txgrepucmulrktbk")
    public suspend fun clusterName(`value`: Output<String>) {
        this.clusterName = value
    }

    /**
     * @param value The name of the Kusto principalAssignment.
     */
    @JvmName("tmmyyoybwekmwlrc")
    public suspend fun principalAssignmentName(`value`: Output<String>) {
        this.principalAssignmentName = value
    }

    /**
     * @param value The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
     */
    @JvmName("qdqcfnipfjhrlhbh")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value Principal type.
     */
    @JvmName("lvmcumcokpgjamfi")
    public suspend fun principalType(`value`: Output<Either<String, PrincipalType>>) {
        this.principalType = value
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("dvroqimjiebqtxim")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("rgooffeyujecmuej")
    public suspend fun role(`value`: Output<Either<String, ClusterPrincipalRole>>) {
        this.role = value
    }

    /**
     * @param value The tenant id of the principal
     */
    @JvmName("evrhvocqnacqjhbm")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("kjmtijvuxrsqqyrv")
    public suspend fun clusterName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the Kusto principalAssignment.
     */
    @JvmName("qtudjmdnnwgygcxh")
    public suspend fun principalAssignmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalAssignmentName = mapped
    }

    /**
     * @param value The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
     */
    @JvmName("cjrgkomjgeuwikiw")
    public suspend fun principalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value Principal type.
     */
    @JvmName("kkcpwhfgvxmudsbb")
    public suspend fun principalType(`value`: Either<String, PrincipalType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal type.
     */
    @JvmName("pwnrdjdgygylnakm")
    public fun principalType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal type.
     */
    @JvmName("xaiyttwlhieewogy")
    public fun principalType(`value`: PrincipalType) {
        val toBeMapped = Either.ofRight<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("tlssdhadanygvfqg")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("awcjensqssknhqwg")
    public suspend fun role(`value`: Either<String, ClusterPrincipalRole>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("vhgeqaunewhakoru")
    public fun role(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClusterPrincipalRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("vbxyhprqqpaxqjaa")
    public fun role(`value`: ClusterPrincipalRole) {
        val toBeMapped = Either.ofRight<String, ClusterPrincipalRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The tenant id of the principal
     */
    @JvmName("cwoudqowxxohyxev")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): ClusterPrincipalAssignmentArgs = ClusterPrincipalAssignmentArgs(
        clusterName = clusterName,
        principalAssignmentName = principalAssignmentName,
        principalId = principalId,
        principalType = principalType,
        resourceGroupName = resourceGroupName,
        role = role,
        tenantId = tenantId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/ClusterPrincipalAssignmentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin

import com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs.builder
import com.pulumi.azurenative.kusto.kotlin.enums.ClusterPrincipalRole
import com.pulumi.azurenative.kusto.kotlin.enums.PrincipalType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Class representing a cluster principal assignment.
 * Azure REST API version: 2022-12-29. Prior API version in Azure Native 1.x: 2021-01-01.
 * Other available API versions: 2023-05-02, 2023-08-15.
 * ## Example Usage
 * ### KustoClusterPrincipalAssignmentsCreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var clusterPrincipalAssignment = new AzureNative.Kusto.ClusterPrincipalAssignment("clusterPrincipalAssignment", new()
 *     {
 *         ClusterName = "kustoCluster",
 *         PrincipalAssignmentName = "kustoprincipal1",
 *         PrincipalId = "87654321-1234-1234-1234-123456789123",
 *         PrincipalType = "App",
 *         ResourceGroupName = "kustorptest",
 *         Role = "AllDatabasesAdmin",
 *         TenantId = "12345678-1234-1234-1234-123456789123",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/kusto/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := kusto.NewClusterPrincipalAssignment(ctx, "clusterPrincipalAssignment", &kusto.ClusterPrincipalAssignmentArgs{
 * 			ClusterName:             pulumi.String("kustoCluster"),
 * 			PrincipalAssignmentName: pulumi.String("kustoprincipal1"),
 * 			PrincipalId:             pulumi.String("87654321-1234-1234-1234-123456789123"),
 * 			PrincipalType:           pulumi.String("App"),
 * 			ResourceGroupName:       pulumi.String("kustorptest"),
 * 			Role:                    pulumi.String("AllDatabasesAdmin"),
 * 			TenantId:                pulumi.String("12345678-1234-1234-1234-123456789123"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.kusto.ClusterPrincipalAssignment;
 * import com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var clusterPrincipalAssignment = new ClusterPrincipalAssignment("clusterPrincipalAssignment", ClusterPrincipalAssignmentArgs.builder()
 *             .clusterName("kustoCluster")
 *             .principalAssignmentName("kustoprincipal1")
 *             .principalId("87654321-1234-1234-1234-123456789123")
 *             .principalType("App")
 *             .resourceGroupName("kustorptest")
 *             .role("AllDatabasesAdmin")
 *             .tenantId("12345678-1234-1234-1234-123456789123")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:kusto:ClusterPrincipalAssignment kustoCluster/kustoprincipal1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Kusto/clusters/{clusterName}/principalAssignments/{principalAssignmentName}
 * ```
 * @property clusterName The name of the Kusto cluster.
 * @property principalAssignmentName The name of the Kusto principalAssignment.
 * @property principalId The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
 * @property principalType Principal type.
 * @property resourceGroupName The name of the resource group containing the Kusto cluster.
 * @property role Cluster principal role.
 * @property tenantId The tenant id of the principal
 */
public data class ClusterPrincipalAssignmentArgs(
    public val clusterName: Output<String>? = null,
    public val principalAssignmentName: Output<String>? = null,
    public val principalId: Output<String>? = null,
    public val principalType: Output<Either<String, PrincipalType>>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val role: Output<Either<String, ClusterPrincipalRole>>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs =
        com.pulumi.azurenative.kusto.ClusterPrincipalAssignmentArgs.builder()
            .clusterName(clusterName?.applyValue({ args0 -> args0 }))
            .principalAssignmentName(principalAssignmentName?.applyValue({ args0 -> args0 }))
            .principalId(principalId?.applyValue({ args0 -> args0 }))
            .principalType(
                principalType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .role(
                role?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterPrincipalAssignmentArgs].
 */
@PulumiTagMarker
public class ClusterPrincipalAssignmentArgsBuilder internal constructor() {
    private var clusterName: Output<String>? = null

    private var principalAssignmentName: Output<String>? = null

    private var principalId: Output<String>? = null

    private var principalType: Output<Either<String, PrincipalType>>? = null

    private var resourceGroupName: Output<String>? = null

    private var role: Output<Either<String, ClusterPrincipalRole>>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("jtdpclvofxmjidxj")
    public suspend fun clusterName(`value`: Output<String>) {
        this.clusterName = value
    }

    /**
     * @param value The name of the Kusto principalAssignment.
     */
    @JvmName("hlevatawovflybbk")
    public suspend fun principalAssignmentName(`value`: Output<String>) {
        this.principalAssignmentName = value
    }

    /**
     * @param value The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
     */
    @JvmName("rpkjytcbudyknehj")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value Principal type.
     */
    @JvmName("ejmqgaexnaeuhrky")
    public suspend fun principalType(`value`: Output<Either<String, PrincipalType>>) {
        this.principalType = value
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("fnlayaxygpptvknw")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("dfptjbwweghvcsfx")
    public suspend fun role(`value`: Output<Either<String, ClusterPrincipalRole>>) {
        this.role = value
    }

    /**
     * @param value The tenant id of the principal
     */
    @JvmName("tpgqukftaccjfnvv")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("hnregootgamclisr")
    public suspend fun clusterName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the Kusto principalAssignment.
     */
    @JvmName("fcvcfjckkbnpligi")
    public suspend fun principalAssignmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalAssignmentName = mapped
    }

    /**
     * @param value The principal ID assigned to the cluster principal. It can be a user email, application ID, or security group name.
     */
    @JvmName("ujmgienvhkcqccfu")
    public suspend fun principalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value Principal type.
     */
    @JvmName("pkbyqrjauyebyirp")
    public suspend fun principalType(`value`: Either<String, PrincipalType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal type.
     */
    @JvmName("ycsjuxwiocotqqse")
    public fun principalType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal type.
     */
    @JvmName("eqfycksohlsawebt")
    public fun principalType(`value`: PrincipalType) {
        val toBeMapped = Either.ofRight<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("oyfbxnkeerigseow")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("prdhpyrxogxidxwo")
    public suspend fun role(`value`: Either<String, ClusterPrincipalRole>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("qbcbxmgiagiderag")
    public fun role(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClusterPrincipalRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Cluster principal role.
     */
    @JvmName("tcavrgabkwgitxmi")
    public fun role(`value`: ClusterPrincipalRole) {
        val toBeMapped = Either.ofRight<String, ClusterPrincipalRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The tenant id of the principal
     */
    @JvmName("ackmvedvlacidcsc")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): ClusterPrincipalAssignmentArgs = ClusterPrincipalAssignmentArgs(
        clusterName = clusterName,
        principalAssignmentName = principalAssignmentName,
        principalId = principalId,
        principalType = principalType,
        resourceGroupName = resourceGroupName,
        role = role,
        tenantId = tenantId,
    )
}
